Repository: kudu
Updated Branches:
  refs/heads/master dad80bd50 -> 04eeacddd


Reduce the number of batches in FuzzTest::TestFuzzHugeBatches

While running fuzz-itest in dist-test with slow mode, asan, it's
often flaky due to timeouts. This test is the main culprit
as it often takes 13 minutes to complete.

This reduces the number of operations in this test and
'update_multiplier' to half for all build types but TSAN (we had already
reduced ops in this case) making it non-flaky.

Change-Id: Ib73220ed342d2417ad65bf1ae705499cab7a9b10
Reviewed-on: http://gerrit.cloudera.org:8080/5223
Reviewed-by: Todd Lipcon <[email protected]>
Tested-by: Kudu Jenkins


Project: http://git-wip-us.apache.org/repos/asf/kudu/repo
Commit: http://git-wip-us.apache.org/repos/asf/kudu/commit/f0247724
Tree: http://git-wip-us.apache.org/repos/asf/kudu/tree/f0247724
Diff: http://git-wip-us.apache.org/repos/asf/kudu/diff/f0247724

Branch: refs/heads/master
Commit: f0247724191d4a7f6b3ada8b961b96e0649cce8a
Parents: dad80bd
Author: David Alves <[email protected]>
Authored: Fri Nov 25 09:28:54 2016 -0800
Committer: David Ribeiro Alves <[email protected]>
Committed: Mon Nov 28 20:12:13 2016 +0000

----------------------------------------------------------------------
 src/kudu/integration-tests/fuzz-itest.cc | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/kudu/blob/f0247724/src/kudu/integration-tests/fuzz-itest.cc
----------------------------------------------------------------------
diff --git a/src/kudu/integration-tests/fuzz-itest.cc 
b/src/kudu/integration-tests/fuzz-itest.cc
index 3468c47..f4a8c8d 100644
--- a/src/kudu/integration-tests/fuzz-itest.cc
+++ b/src/kudu/integration-tests/fuzz-itest.cc
@@ -474,18 +474,18 @@ TEST_F(FuzzTest, TestFuzz) {
 }
 
 // Generates a random test case, but the UPDATEs are all repeated many times.
-// This results in very row_keye batches which are likely to span multiple 
delta blocks
+// This results in very large batches which are likely to span multiple delta 
blocks
 // when flushed.
 TEST_F(FuzzTest, TestFuzzHugeBatches) {
   SeedRandom();
   vector<TestOp> test_ops;
-  GenerateTestCase(&test_ops, AllowSlowTests() ? 1000 : 50);
+  GenerateTestCase(&test_ops, AllowSlowTests() ? 500 : 50);
   int update_multiplier;
 #ifdef THREAD_SANITIZER
   // TSAN builds run more slowly, so 1000 can cause timeouts.
   update_multiplier = 100;
 #else
-  update_multiplier = 1000;
+  update_multiplier = 500;
 #endif
   RunFuzzCase(test_ops, update_multiplier);
 }
@@ -474,18 +474,18 @@ TEST_F(FuzzTest, TestFuzz) {
   int update_multiplier;
 #ifdef THREAD_SANITIZER
-  // TSAN builds run more slowly, so 1000 can cause timeouts.
+  // TSAN builds run more slowly, so 500 can cause timeouts.
   update_multiplier = 100;
 #else

Reply via email to